@@ -130,8 +130,14 @@ public class LoginConnector implements Connector<SessionData, LoginResponseMto>
         RequestBuilder builder = RequestBuilder.post(createUrl());
         builder.setCharset(Charset.forName("UTF-8"));
         String hostname = credentials.getHost();
-        if (credentials.getHostConfiguration().isForwardHostHeader() && !Strings.isEmpty(hostname)) {
-            builder.addHeader(RequestUtil.HEADER_HOST, hostname);
+        String xHostname = credentials.getXHost();
+        if (credentials.getHostConfiguration().isForwardHostHeader()) {
+            if (!Strings.isEmpty(hostname)) {
+                builder.addHeader(RequestUtil.HEADER_HOST, hostname);
+            }
+            if (!Strings.isEmpty(xHostname)) {
+                builder.addHeader(RequestUtil.HEADER_X_HOST, xHostname);
+            }
         }
         String forwardedFor = credentials.getForwardedFor();
         if (!Strings.isEmpty(forwardedFor)) {
