@@ -67,6 +67,8 @@ import javax.ws.rs.core.Response;
 
 import com.openexchange.mobile.api.facade.auth.SessionData;
 import com.openexchange.mobile.api.facade.endpoints.requests.AccountRequestBody;
+import com.openexchange.mobile.api.facade.endpoints.requests.AutoconfigData;
+import com.openexchange.mobile.api.facade.endpoints.requests.AutoconfigRequestBody;
 import com.openexchange.mobile.api.facade.endpoints.responses.AccountResponseBodyV2;
 import com.openexchange.mobile.api.facade.endpoints.responses.AccountsResponseBodyV2;
 import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;
@@ -91,8 +93,8 @@ public class AccountsEndpointV2 {
     @GET
     @Produces(MediaType.APPLICATION_JSON)
     public Response getAccounts(@Context HttpServletRequest request) {
-        log.info("Retrieve all accounts");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Retrieve all accounts");
         String language = RequestUtil.getLanguage(request);
         List<MailAccountData> accounts = accountsService.getAccountsV2(sessionData, language);
         AccountsResponseBodyV2 responseBody = new AccountsResponseBodyV2(accounts);
@@ -103,8 +105,8 @@ public class AccountsEndpointV2 {
     @Path("/{id}")
     @Produces(MediaType.APPLICATION_JSON)
     public Response getAccount(@Context HttpServletRequest request, @PathParam("id") String accountId) {
-        log.info("Retrieve specific account");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Retrieve specific account");
         String language = RequestUtil.getLanguage(request);
         MailAccountData account = accountsService.getAccountV2(sessionData, accountId, language);
         AccountResponseBodyV2 responseBody = new AccountResponseBodyV2(account);
@@ -115,11 +117,12 @@ public class AccountsEndpointV2 {
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
     public Response createAccount(@Context HttpServletRequest request, String rawRequestBody) {
-        log.info("Create account");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Create account");
         AccountRequestBody requestBody = JacksonUtil.parse(rawRequestBody, AccountRequestBody.class);
         boolean forceInsecureConnection = requestBody.getForceInsecureConnection() != null && requestBody.getForceInsecureConnection();
-        MailAccountData account = accountsService.createAccount(sessionData, new MailAccountData(requestBody), forceInsecureConnection);
+        boolean ignoreInvalidTransport = requestBody.getIgnoreInvalidTransport() != null && requestBody.getIgnoreInvalidTransport();
+        MailAccountData account = accountsService.createAccount(sessionData, new MailAccountData(requestBody), forceInsecureConnection, ignoreInvalidTransport);
         AccountResponseBodyV2 responseBody = new AccountResponseBodyV2(account);
         return RequestUtil.jsonResponse(responseBody);
     }
@@ -129,14 +132,15 @@ public class AccountsEndpointV2 {
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
     public Response updateAccount(@Context HttpServletRequest request, @PathParam("id") String accountId, String rawRequestBody) {
-        log.info("Update account");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Update account");
         AccountRequestBody requestBody = JacksonUtil.parse(rawRequestBody, AccountRequestBody.class);
         if (!accountId.equals(requestBody.getId())) {
             throw ApiFacadeException.badRequest(ApiFacadeException.Code.INVALID_ACCOUNT_DATA, "Account Ids don't match");
         }
         boolean forceInsecureConnection = requestBody.getForceInsecureConnection() != null && requestBody.getForceInsecureConnection();
-        MailAccountData account = accountsService.updateAccount(sessionData, new MailAccountData(requestBody), forceInsecureConnection);
+        boolean ignoreInvalidTransport = requestBody.getIgnoreInvalidTransport() != null && requestBody.getIgnoreInvalidTransport();
+        MailAccountData account = accountsService.updateAccount(sessionData, new MailAccountData(requestBody), forceInsecureConnection, ignoreInvalidTransport);
         AccountResponseBodyV2 responseBody = new AccountResponseBodyV2(account);
         return RequestUtil.jsonResponse(responseBody);
     }
@@ -145,10 +149,26 @@ public class AccountsEndpointV2 {
     @Path("/{id}")
     @Produces(MediaType.APPLICATION_JSON)
     public Response deleteAccount(@Context HttpServletRequest request, @PathParam("id") String accountId) {
-        log.info("Delete account");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Delete account");
         boolean isDeleted = accountsService.deleteAccount(sessionData, accountId);
         return Response.status(isDeleted ? HttpStatus.SC_OK : HttpStatus.SC_NOT_FOUND).build();
     }
 
+    @POST
+    @Path("/autoconfig")
+    @Consumes(MediaType.APPLICATION_JSON)
+    @Produces(MediaType.APPLICATION_JSON)
+    public Response autoconfigAccount(@Context HttpServletRequest request, String rawRequestBody) {
+        SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Autoconfigure account");
+        AutoconfigRequestBody requestBody = JacksonUtil.parse(rawRequestBody, AutoconfigRequestBody.class);
+        RequestUtil.checkParam("mailAddress", requestBody.getMailAddress());
+        RequestUtil.checkParam("password", requestBody.getPassword());
+        AutoconfigData autoconfigData = new AutoconfigData(requestBody);
+        MailAccountData template = accountsService.autoconfigAccount(sessionData, autoconfigData);
+        AccountResponseBodyV2 responseBody = new AccountResponseBodyV2(template);
+        return RequestUtil.jsonResponse(responseBody);
+    }
+
 }
