@@ -91,6 +91,8 @@ public class Account {
 
     private StandardFolders standardFolders;
 
+    private final boolean pop3Account;
+
     public Account(AccountMto accountMto, UserMto userMto, String defaultSendAddress) {
         this(accountMto, userMto, defaultSendAddress, null);
     }
@@ -126,6 +128,7 @@ public class Account {
             this.folders = folders;
             standardFolders = createStandardFolders(folders);
         }
+        pop3Account = accountMto.isPop3Account();
     }
 
     public Account withFolders(List<Folder> folders) {
