@@ -57,6 +57,7 @@ import com.openexchange.mobile.api.facade.connectors.ConnectorFactory;
 import com.openexchange.mobile.api.facade.connectors.ConnectorFactoryFactory;
 import com.openexchange.mobile.api.facade.connectors.JsLob;
 import com.openexchange.mobile.api.facade.connectors.impl.AccountsConnector;
+import com.openexchange.mobile.api.facade.connectors.impl.AutoconfigureAccountConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.CreateAccountConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.DeleteAccountConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.GetAccountConnector;
@@ -73,6 +74,7 @@ import com.openexchange.mobile.api.facade.connectors.responses.RawResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.UserResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.mtos.AccountMto;
 import com.openexchange.mobile.api.facade.connectors.responses.mtos.UserMto;
+import com.openexchange.mobile.api.facade.endpoints.requests.AutoconfigData;
 import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;
 import com.openexchange.mobile.api.facade.models.Account;
 import com.openexchange.mobile.api.facade.models.MailAccountData;
@@ -216,11 +218,11 @@ public class AccountsService {
         return response.getData();
     }
 
-    public MailAccountData createAccount(SessionData sessionData, MailAccountData account, boolean forceInsecureConnection) {
+    public MailAccountData createAccount(SessionData sessionData, MailAccountData account, boolean forceInsecureConnection, boolean ignoreInvalidTransport) {
         ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
         // 1. Validate account data.
         // 2. Throw exception indicating invalid account data if not successful validated.
-        validateAccountData(connectorFactory, sessionData, account, forceInsecureConnection);
+        validateAccountData(connectorFactory, sessionData, account, forceInsecureConnection, ignoreInvalidTransport);
         // 3. If successfully validated create new account
         CreateAccountConnector connector = connectorFactory.getCreateAccountConnector(sessionData, account);
         MailAccountResponseMto response = connector.execute();
@@ -228,11 +230,11 @@ public class AccountsService {
         return MailAccountBaseConnector.map(response);
     }
 
-    public MailAccountData updateAccount(SessionData sessionData, MailAccountData account, boolean forceInsecureConnection) {
+    public MailAccountData updateAccount(SessionData sessionData, MailAccountData account, boolean forceInsecureConnection, boolean ignoreInvalidTransport) {
         ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
         // 1. Validate account data.
         // 2. Throw exception indicating invalid account data if not successful validated.
-        validateAccountData(connectorFactory, sessionData, account, forceInsecureConnection);
+        validateAccountData(connectorFactory, sessionData, account, forceInsecureConnection, ignoreInvalidTransport);
         // 3. If successfully validated update account.
         UpdateAccountConnector connector = connectorFactory.getUpdateAccountConnector(sessionData, account);
         MailAccountResponseMto response = connector.execute();
@@ -240,8 +242,8 @@ public class AccountsService {
         return MailAccountBaseConnector.map(response);
     }
 
-    private void validateAccountData(ConnectorFactory connectorFactory, SessionData sessionData, MailAccountData account, boolean forceInsecureConnection) {
-        ValidateAccountConnector validateConnector = connectorFactory.getValidateAccountConnector(sessionData, account, forceInsecureConnection);
+    private void validateAccountData(ConnectorFactory connectorFactory, SessionData sessionData, MailAccountData account, boolean forceInsecureConnection, boolean ignoreInvalidTransport) {
+        ValidateAccountConnector validateConnector = connectorFactory.getValidateAccountConnector(sessionData, account, forceInsecureConnection, ignoreInvalidTransport);
         BooleanResponseMto response = validateConnector.execute();
         if (ValidateAccountConnector.map(response)) {
             return;
@@ -266,4 +268,11 @@ public class AccountsService {
         }
     }
 
+    public MailAccountData autoconfigAccount(SessionData sessionData, AutoconfigData autoconfigData) {
+        ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
+        AutoconfigureAccountConnector connector = connectorFactory.getAutoconfigureAccountConnector(sessionData, autoconfigData);
+        MailAccountResponseMto response = connector.execute();
+        return new MailAccountData(response.getData());
+    }
+
 }
